pub struct SpringConfig {
pub mass: f32,
pub stiffness: f32,
pub damping: f32,
}Expand description
Spring physics configuration: mass-spring-damper.
The four preset constants are calibrated to feel competitive with modern native motion (UIKit defaults, Material 3 motion). Authors pick a preset; ad-hoc tuning is intentionally not exposed to keep the surface area small.
Fields
mass: f32stiffness: f32damping: f32Implementations
Sourceimpl SpringConfig
impl SpringConfig