pub struct SelectionRange {
pub anchor: SelectionPoint,
pub head: SelectionPoint,
}Expand description
A non-empty selection range. anchor is where the user started
(pointer-down); head is where they ended up (pointer current /
last move). The pair may be in tree order or reversed.
Fields
anchor: SelectionPointhead: SelectionPointTrait Implementations
Sourceimpl Clone for SelectionRange
impl Clone for SelectionRange
Sourcefn clone(&self) -> SelectionRange
fn clone(&self) -> SelectionRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SelectionRange
impl Debug for SelectionRange
Sourceimpl PartialEq for SelectionRange
impl PartialEq for SelectionRange
Sourcefn eq(&self, other: &SelectionRange) -> bool
fn eq(&self, other: &SelectionRange) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SelectionRange
impl StructuralPartialEq for SelectionRange