pub struct TextLine {
pub text: String,
pub width: f32,
pub y: f32,
pub baseline: f32,
pub rtl: bool,
}Fields
text: Stringwidth: f32y: f32Top offset from the text layout origin, in logical pixels.
baseline: f32Baseline offset from the text layout origin, in logical pixels.
rtl: boolParagraph direction as resolved by the shaping engine.