replace_selection

Function replace_selection 

pub fn replace_selection(
    value: &mut String,
    selection: &mut TextSelection,
    replacement: &str,
)
Replace the selected substring (or insert at the caret when the selection is collapsed) with replacement. Updates selection to a collapsed caret immediately after the inserted text.